==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/PersistenceParser__24FloatHandlerCreator.h <==
// class gnu.java.beans.decoder.PersistenceParser$FloatHandlerCreator

// class file dependencies
// @dep_class 189ad63af583f233 gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator_H_
#define _JC_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_gnu_java_beans_decoder_PersistenceParser$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_refs	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$refs	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$object	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$object;

typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vmethods	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtable	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtable;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtype	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$method$_init$abe75c23fad35364(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$object *, struct _jc_gnu_java_beans_decoder_PersistenceParser$object *);

// Virtual methods
extern struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object *_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$method$createHandler$5a0dc6a0283274e0(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$method_info$createHandler$5a0dc6a0283274e0;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vmethods {
	struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object	*(*createHandler$5a0dc6a0283274e0)(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vmethods	gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator;
};

// Vtype
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_refs {
	struct _jc_gnu_java_beans_decoder_PersistenceParser$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$refs {
    _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_refs	gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_nonrefs	gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$object {
	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtype	*vtype;
	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtype _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$class_object;

#endif	/* _JC_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/PersistenceParser__24FloatHandlerCreator.h <==
// class gnu.java.beans.decoder.PersistenceParser$FloatHandlerCreator

// class file dependencies
// @dep_class db48d7714768e8a0 gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator_H_
#define _JC_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_gnu_java_beans_decoder_PersistenceParser$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_refs	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$refs	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$object	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$object;

typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vmethods	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtable	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtable;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtype	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$method$_init$abe75c23fad35364(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$object *, struct _jc_gnu_java_beans_decoder_PersistenceParser$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object *_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$method$createHandler$5a0dc6a0283274e0(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$method_info$createHandler$5a0dc6a0283274e0;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vmethods {
	struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object	*(*createHandler$5a0dc6a0283274e0)(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vmethods	gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator;
};

// Vtype
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_refs {
	struct _jc_gnu_java_beans_decoder_PersistenceParser$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$refs {
    _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_refs	gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$sub_nonrefs	gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$object {
	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtype	*vtype;
	_jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$vtype _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator$class_object;

#endif	/* _JC_gnu_java_beans_decoder_PersistenceParser__24FloatHandlerCreator_H_ */
